@@ -13,21 +13,14 @@ use Benchmark::Timer;
 use FileHandle;
 use Test::ConfigureGrepmail;
 use File::Copy;
-use File::Spec;
-
-BEGIN
-{
-  die "Need Benchmark::Timer 0.6 or higher"
-    unless $Benchmark::Timer::VERSION >= 0.6;
-}
 
 my $MAILBOX_SIZE = 10_000_000;
 my $TEMP_MAILBOX = 't/temp/bigmailbox.txt';
 
 my @IMPLEMENTATIONS_TO_TEST = (
-#'Perl',
-#'Grep',
-#'Cache Init',
+'Perl',
+'Grep',
+'Cache Init',
 'Cache Use',
 );
 
@@ -100,7 +93,6 @@ sub CreateInputFiles
     close FILE;
 
     open FILE, ">$filename";
-    binmode FILE;
 
     my $number = 0;
 
@@ -202,8 +194,6 @@ sub CollectData
       my $new_test = $test;
       $new_test =~ s/\bgrepmail\b/$^X $grepmail/g;
 
-      print "$impl ($old_or_new)\n";
-
       Test::ConfigureGrepmail::Set_Caching_And_Grep($grepmail,
         @{$settings{$impl}});
 
@@ -213,8 +203,6 @@ sub CollectData
       my $count = 0;
       while ($count - 1 < 10 || $t->need_more_samples($label))
       {
-        print ".";
-
         unlink 't/temp/cache' if $impl eq 'Cache Init';
 
         $t->start($label);
@@ -225,9 +213,7 @@ sub CollectData
         $count++;
       }
 
-      print "\n\n";
-
-      print $t->get_report($label);
+      $t->report($label);
 
       # Fake a benchmark object so we can compare later using Benchmark
       $data{$label} = new Benchmark;
